"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const { log } = console;
const logger = {
    debugPrefix: '*** ',
    debug: 'debug',
    error: 'error',
    fatal: 'fatal',
    info: 'info',
    jobs: 'jobs',
    profile: 'PROFILE',
    warn: 'warn',
    colormap: {
        DEBUG: chalk_1.default.cyanBright,
        debug: chalk_1.default.cyan,
        ERROR: chalk_1.default.redBright,
        error: chalk_1.default.red,
        FATAL: chalk_1.default.redBright,
        fatal: chalk_1.default.red,
        INFO: chalk_1.default.greenBright,
        info: chalk_1.default.green,
        JOBS: chalk_1.default.blueBright,
        jobs: chalk_1.default.blue,
        PROFILE: chalk_1.default.magentaBright,
        profile: chalk_1.default.magenta,
        WARN: chalk_1.default.yellowBright,
        warn: chalk_1.default.yellow
    },
    log: function (level, text, debug) {
        if (level !== this.debug) {
            log(this.colorize(level, text));
        }
        else if (debug) {
            log(this.colorize(level, this.debugPrefix + text));
        }
    },
    colorize: function (level, text) {
        if (!level || level.length === 0) {
            return text;
        }
        let color = this.colormap[level];
        if (!color) {
            switch (true) {
                case this.checkFor(level, "info"):
                    color = this.colormap["info"];
                    break;
                case this.checkFor(level, "warn"):
                    color = this.colormap["warn"];
                    break;
                case this.checkFor(level, "error"):
                    color = this.colormap["error"];
                    break;
                case this.checkFor(level, "fatal"):
                    color = this.colormap["fatal"];
                    break;
                case this.checkFor(level, "jobs"):
                    color = this.colormap["jobs"];
                    break;
                case this.checkFor(level, "debug"):
                    color = this.colormap["debug"];
                    break;
                case this.checkFor(level, "profile"):
                    color = this.colormap["profile"];
                    break;
                default:
                    break;
            }
        }
        if (color) {
            return color(text);
        }
        else {
            return text;
        }
    },
    checkFor: function (input, term) {
        return (input.indexOf(term) != -1);
    }
};
exports.default = logger;
